Replayable

Derive Macro Replayable 

#[derive(Replayable)]
{
    // Attributes available to this derive:
    #[etch]
}
Derive Replayable for a struct with #[etch(collection = N)] fields.

Generates an apply method that routes ops to the correct field based on the collection id, using apply_op for BTreeMap fields and apply_op_hash for HashMap fields.